#!c:/perl/bin/perl.exe
use warnings;
use strict;
use diagnostics;

my @gc_contents = (20,30,40,50,60,70,80,90);

my $seq_length = 50;

my $number_of_seqs = 10000;

foreach my $gc (@gc_contents) {
	
	warn "Processing $gc percent GC\n";
	
	open (my $out,'>',"$gc-percent.fastq") or die "Can't write to '$gc-percent.fastq': $!";
	
	# Loop once for each sequence we want to generate
	for my $seq_index (1..$number_of_seqs) {
		
		my @sequence;
		my @quality;
		
		# Loop through the bases to generate adding a new base and quality
		# char for each position
		for (1..$seq_length) {
			
			# Generate a new base to append to the existing sequence
			if (rand()*100 < $gc) {
				# It's going to be G/C
				if (rand() < 0.5) {
					push @sequence,'G';
				}
				else {
					push @sequence,'C';
				}
			}
			else {
				# It's going to be A/T
				if (rand() < 0.5) {
					push @sequence,'A';
				}
				else {
					push @sequence,'T';
				}
			}
			
			# Generate a new quality score.  Use a log scale so we
			# bias towards higher numbers
			my $score = int(sqrt(rand(30*30)));
			
			# The encoding for the score is that we have to add an
			# offset of 64 (for illumina encoding), and then use the
			# ascii representation of that number
			$score += 64;
			push @quality,chr($score);
			
		}
		
		print $out "\@sequence_$seq_index\n";
		print $out join("",@sequence),"\n";
		print $out "+sequence_$seq_index\n";
		print $out join("",@quality),"\n";
		
	}
	
	close $out or die "Can't close $gc-percent.fastq: $!";
	
	
}
